@@ -50,31 +50,41 @@ export class MazeView extends DOMWidgetView {
   method_changed = () => {
     let current_call: { method_name: string; params: any; cb: any } =
       JSON.parse(this.model.get('current_call'));
-    queue.add(() => {
-      let ret =
-        typeof this[current_call.method_name as keyof MazeView] === 'function'
-          ? this[current_call.method_name as keyof MazeView].apply(
-              this,
-              current_call.params
-            )
-          : null;
 
-      console.log('current_call in promise', current_call);
-      let that = this;
-      return Promise.resolve(ret).then(function (x) {
-        // console.log("reached in promise");
-        let data = JSON.stringify({
-          value: x,
-          cb: +new Date(),
-          params: current_call.params,
-          method: current_call.method_name,
+    if (current_call.method_name === 'halt') {
+      return this.halt();
+    } else {
+      queue.add(() => {
+        return new Promise((resolve) => {
+          let ret =
+            typeof this[current_call.method_name as keyof MazeView] ===
+            'function'
+              ? this[current_call.method_name as keyof MazeView].apply(
+                  this,
+                  current_call.params
+                )
+              : null;
+
+          console.log('current_call in promise -> new code', current_call);
+          let that = this;
+          Promise.resolve(ret)
+            .then(function (x) {
+              // console.log("reached in promise");
+              let data = JSON.stringify({
+                value: x,
+                cb: +new Date(),
+                params: current_call.params,
+                method: current_call.method_name,
+              });
+              console.log('setting return', data);
+              that.model.set('method_return', data);
+              that.model.save_changes();
+              return data;
+            })
+            .then(resolve);
         });
-        console.log('setting return', data);
-        that.model.set('method_return', data);
-        that.model.save_changes();
-        return data;
       });
-    });
+    }
   };
 
   draw_all = (
@@ -85,7 +95,8 @@ export class MazeView extends DOMWidgetView {
     robots = [],
     objects: any = {},
     tileMap: any = {},
-    tiles: any = []
+    tiles: any = [],
+    pending_goals: any = []
   ) => {
     return this.world_model.init(
       rows,
@@ -95,10 +106,15 @@ export class MazeView extends DOMWidgetView {
       robots,
       objects,
       tileMap,
-      tiles
+      tiles,
+      pending_goals
     );
   };
 
+  halt = () => {
+    return queue.clear();
+  };
+
   move_to = (index: number, x: number, y: number) => {
     return this.world_model.robots[index]?.move_to(x, y);
   };
@@ -119,6 +135,10 @@ export class MazeView extends DOMWidgetView {
     return this.world_model.draw_wall(x, y, dir);
   };
 
+  add_object = (x: number, y: number, obj_name: string, val: number) => {
+    return this.world_model.draw_object(x, y, { [obj_name]: val });
+  };
+
   update_object = (x: number, y: number, val: number) => {
     return this.world_model.update_object(x, y, val);
   };
@@ -131,6 +151,10 @@ export class MazeView extends DOMWidgetView {
     return this.world_model.remove_wall(x, y, dir);
   };
 
+  set_succes_msg = (msg: string[]) => {
+    return this.world_model.success_msg(msg);
+  };
+
   render() {
     //set methods
     this.method_changed();
