@@ -16,9 +16,9 @@ from .goal import class_list, Goal, PositionGoal
 def cstr(s, color='black'):
     return "<text style=color:{}>{}</text>".format(color, s)
 
-def print_success(msg, color="green"):
+def print_success(msg, color="blue"):
     if msg is not None:
-        display(html_print(cstr("✓ {}".format(msg), color=color))) 
+        display(html_print(cstr("\N{speech balloon} {}".format(msg), color=color))) 
 
 def print_error(error):
     if error is not None:
