@@ -180,7 +180,7 @@ class Robot():
 
         """
         self.count_report = msg
-        print_success("🤔 {}".format(msg))
+        print_success("{}".format(msg))
     
     def cell(self):
         return self.world_model.cells[self.x - 1][self.y - 1 ]
